@@ -22,7 +22,7 @@ template_str = f"""
 FOUNDATIONLIVE_TEMPLATES_OUTPUT_DIRECTORY={user_data_path}
 FOUNDATIONLIVE_GOOGLESHEETS_AUTH_JSON_FILE_PATH={sheets_auth_json_path}
 FOUNDATIONLIVE_DATA_PATH={time_data_path}
-FOUNDATIONLIVE_GOOGLESHEETS_WORKBOOK_NAME=where does my time go
+FOUNDATIONLIVE_GOOGLESHEETS_SPREADSHEET_NAME=where does my time go
 HOURLY_RATE=100.00
 """.strip()  # noqa: E501
 
